#!/bin/bash
#this is the shell script executes the program (ChemConsole v-0.4)
#Edit this to work with you system
#

#The location of JRE directory 
J_HOME=/usr/lib/java

#The location the ChemConsole directory
C_HOME=/home/nathan/Jfc/Chemc-0.4

#The location of the Swing directory
S_HOME=/usr/lib/swing1

#Don't edit beyond this point unless you know what you are doing.
jre -classpath $J_HOME/lib/classes.zip:$C_HOME/ChemConsole.jar:$C_HOME/rmic:$S_HOME/swingall.jar ChemConsole

